@@ -30,7 +30,7 @@ from linaro_image_tools.hwpack.hardwarepack_format import (
     HardwarePackFormatV1,
     HardwarePackFormatV2,
     HardwarePackFormatV3,
-    )
+)
 
 from hwpack_fields import (
     ARCHITECTURES_FIELD,
@@ -44,6 +44,8 @@ from hwpack_fields import (
     DD_FIELD,
     DTB_ADDR_FIELD,
     DTB_FILE_FIELD,
+    DEFAULT_BOOTLOADER,
+    DTB_FILES_FIELD,
     ENV_DD_FIELD,
     EXTRA_BOOT_OPTIONS_FIELD,
     EXTRA_SERIAL_OPTIONS_FIELD,
@@ -69,7 +71,9 @@ from hwpack_fields import (
     SAMSUNG_BL1_LEN_FIELD,
     SAMSUNG_BL1_START_FIELD,
     SAMSUNG_BL2_LEN_FIELD,
+    SAMSUNG_BL2_START_FIELD,
     SAMSUNG_ENV_LEN_FIELD,
+    SAMSUNG_ENV_START_FIELD,
     SERIAL_TTY_FIELD,
     SNOWBALL_STARTUP_FILES_CONFIG_FIELD,
     SOURCES_FIELD,
@@ -85,6 +89,8 @@ from hwpack_fields import (
     hwpack_v3_layout,
 )
 
+import logging
+
 
 class HwpackConfigError(Exception):
     pass
@@ -152,8 +158,11 @@ class Config(object):
         # difference to what is returned when querying the object.
         #
         # self.allow_unset_bootloader allows for both modes of operation.
+        self.logger = logging.getLogger('linaro_image_tools')
         self.allow_unset_bootloader = allow_unset_bootloader
-        self.bootloader = None
+        self.board = board
+        self._bootloader = bootloader
+
         obfuscated_e = None
         obfuscated_yaml_e = ""
         try:
@@ -171,12 +180,10 @@ class Config(object):
                 self.parser = yaml.safe_load(fp)
             except yaml.YAMLError, e:
                 obfuscated_yaml_e = re.sub(r"([^ ]https://).+?(@)",
-                                      r"\1***\2", str(e))
+                                           r"\1***\2", str(e))
             else:
                 # If YAML parsed OK, we don't have an error.
                 obfuscated_e = None
-                self.set_board(board)
-                self.set_bootloader(bootloader)
 
         if obfuscated_e:
             # If INI parsing from ConfigParser or YAML parsing failed,
@@ -188,12 +195,12 @@ class Config(object):
                    obfuscated_yaml_e)
             raise ConfigParser.Error(msg)
 
-    def set_bootloader(self, bootloader):
-        """Set bootloader used to look up configuration in bootloader section.
+    def _get_bootloader(self):
+        """Returns the bootloader associated with this config.
 
         If bootloader is None / empty and there is only one bootloader
-        available, use that.
-        """
+        available, use that."""
+        bootloader = self._bootloader
         if not bootloader:
             # Auto-detect bootloader. If there is a single bootloader specified
             # then use it, else, error.
@@ -201,14 +208,33 @@ class Config(object):
             if isinstance(bootloaders, dict):
                 # We have a list of bootloaders in the expected format
                 bootloaders = bootloaders.keys()
-                if len(bootloaders) == 1:
-                    bootloader = bootloaders[0]
+                bootloader = bootloaders[0]
+                if len(bootloaders) > 1:
+                    # We have more than one bootloader, use 'u_boot'.
+                    if DEFAULT_BOOTLOADER in bootloaders:
+                        bootloader = DEFAULT_BOOTLOADER
+                        self.logger.warning('WARNING: no bootloader specified '
+                                            'on the command line. Defaulting '
+                                            'to \'%s\'.' % DEFAULT_BOOTLOADER)
+                        self.logger.warning('WARNING: specify another '
+                                            'bootloader if this is not the '
+                                            'correct one to use.')
+                    else:
+                        self.logger.warning('Default bootloader \'%s\' not '
+                                            'found. Will try to use \'%s\'. '
+                                            'instead.' % (DEFAULT_BOOTLOADER,
+                                                          bootloader))
+            # bootloader is None: since we are here, set it so we do not
+            # have to go through all the config retrieval again.
+            self._bootloader = bootloader
+        return bootloader
 
-        self.bootloader = bootloader
+    def _set_bootloader(self, value):
+        """Set bootloader used to look up configuration in bootloader section.
+        """
+        self._bootloader = value
 
-    def set_board(self, board):
-        """Set board used to look up per-board configuration"""
-        self.board = board
+    bootloader = property(_get_bootloader, _set_bootloader)
 
     def get_bootloader_list(self):
         if isinstance(self.bootloaders, dict):
@@ -246,11 +272,10 @@ class Config(object):
 
         if self.format.has_v2_fields:
             # Check config for all bootloaders if one isn't specified.
-            if self.bootloader == None and self._is_v3:
+            if not self.bootloader and self._is_v3:
                 for bootloader in self.get_bootloader_list():
-                    self.set_bootloader(bootloader)
+                    self.bootloader = bootloader
                     self.validate_bootloader_fields()
-                self.set_bootloader(None)
             else:
                 self.validate_bootloader_fields()
 
@@ -269,14 +294,17 @@ class Config(object):
             self._validate_vmlinuz()
             self._validate_initrd()
             self._validate_dtb_file()
+            self._validate_dtb_files()
             self._validate_mmc_id()
             self._validate_extra_boot_options()
             self._validate_boot_script()
-            self._validate_extra_serial_opts()
+            self._validate_extra_serial_options()
             self._validate_snowball_startup_files_config()
             self._validate_samsung_bl1_start()
             self._validate_samsung_bl1_len()
+            self._validate_samsung_env_start()
             self._validate_samsung_env_len()
+            self._validate_samsung_bl2_start()
             self._validate_samsung_bl2_len()
 
         self._validate_sources()
@@ -305,7 +333,7 @@ class Config(object):
             return HardwarePackFormatV3()
         else:
             raise HwpackConfigError("Format version '%s' is not supported." %
-                                        format_string)
+                                    format_string)
 
     @property
     def name(self):
@@ -320,7 +348,7 @@ class Config(object):
     def include_debs(self):
         """Whether the hardware pack should contain .debs. A bool."""
         try:
-            if self._get_option(self.INCLUDE_DEBS_KEY) == None:
+            if self._get_option(self.INCLUDE_DEBS_KEY) is None:
                 return True
             try:
                 return self._get_option_bool(self.INCLUDE_DEBS_KEY)
@@ -391,7 +419,7 @@ class Config(object):
                 else:
                     if len(value.keys()) > 1:
                         raise HwpackConfigError("copy_files entry found with"
-                            "more than one destination")
+                                                "more than one destination")
                     source_path = value.keys()[0]
                     dest_path = value[source_path]
 
@@ -399,7 +427,8 @@ class Config(object):
                     # Target path should be relative, or start with /boot - we
                     # don't support to copying to anywhere other than /boot.
                     if dest_path[0] == "/":
-                        raise HwpackConfigError("copy_files destinations must"
+                        raise HwpackConfigError(
+                            "copy_files destinations must"
                             "be relative to /boot or start with /boot.")
                     dest_path = os.path.join("/boot", dest_path)
 
@@ -525,11 +554,11 @@ class Config(object):
                 result = self._get_v3_option([BOARDS_FIELD, self.board] + keys)
 
             # If a board specific value isn't found, look for a global one
-            if result == None:
+            if result is None:
                 result = self._get_v3_option(keys)
 
             # If no value is found, bail early (return None)
-            if result == None:
+            if result is None:
                 return None
 
             # <v3 compatibility: Lists of items can be converted to strings
@@ -594,7 +623,7 @@ class Config(object):
                                            join_list_with=" ")
 
     @property
-    def extra_serial_opts(self):
+    def extra_serial_options(self):
         """Extra serial options.
 
         A str.
@@ -820,6 +849,14 @@ class Config(object):
         """
         return self._get_option(DTB_FILE_FIELD)
 
+    @property
+    def dtb_files(self):
+        """
+        The list of dtb files.
+        :return: A list of dtb files
+        """
+        return self._get_option(DTB_FILES_FIELD)
+
     @property
     def samsung_bl1_start(self):
         """BL1 start offset for Samsung boards.
@@ -836,6 +873,14 @@ class Config(object):
         """
         return self._get_option(SAMSUNG_BL1_LEN_FIELD)
 
+    @property
+    def samsung_env_start(self):
+        """Env start offset for Samsung boards.
+
+        A str.
+        """
+        return self._get_option(SAMSUNG_ENV_START_FIELD)
+
     @property
     def samsung_env_len(self):
         """Env length for Samsung boards.
@@ -844,6 +889,14 @@ class Config(object):
         """
         return self._get_option(SAMSUNG_ENV_LEN_FIELD)
 
+    @property
+    def samsung_bl2_start(self):
+        """BL2 start offset for Samsung boards.
+
+        A str.
+        """
+        return self._get_option(SAMSUNG_BL2_START_FIELD)
+
     @property
     def samsung_bl2_len(self):
         """BL2 length for Samsung boards.
@@ -899,8 +952,8 @@ class Config(object):
         if not format:
             raise HwpackConfigError("Empty value for format")
         if not format.is_supported:
-            raise HwpackConfigError("Format version '%s' is not supported." % \
-                                        format)
+            raise HwpackConfigError("Format version '%s' is not supported." %
+                                    format)
 
     def _assert_matches_pattern(self, regex, config_item, error_message):
             if re.match(regex, config_item) is None:
@@ -953,7 +1006,16 @@ class Config(object):
             return "No " + thing + " in the [" + v2_section + "] section"
 
     def _validate_dtb_file(self):
-        dtb_file = self.dtb_file
+        self._check_single_dtb_file(self.dtb_file)
+
+    def _validate_dtb_files(self):
+        dtb_files = self.dtb_files
+        if dtb_files:
+            for dtb_file in dtb_files:
+                for _, src in dtb_file.iteritems():
+                    self._check_single_dtb_file(src)
+
+    def _check_single_dtb_file(self, dtb_file):
         if dtb_file is not None:
             self._assert_matches_pattern(
                 self.GLOB_REGEX, dtb_file, "Invalid path: %s" % dtb_file)
@@ -962,7 +1024,7 @@ class Config(object):
         # Optional and tricky to determine a valid pattern.
         pass
 
-    def _validate_extra_serial_opts(self):
+    def _validate_extra_serial_options(self):
         # Optional and tricky to determine a valid pattern.
         pass
 
@@ -1005,7 +1067,7 @@ class Config(object):
             raise HwpackConfigError("Invalid %s address: %s" %
                                     (name, self._get_option(key)))
 
-        if addr == None:
+        if addr is None:
             return
 
         if not re.match(r"^0x[a-fA-F0-9]{8}$", addr):
@@ -1048,8 +1110,8 @@ class Config(object):
         mmc_id = self.mmc_id
         if not mmc_id:
             raise HwpackConfigError(
-                "No mmc_id in the [%s] section" % \
-                    self.MAIN_SECTION)
+                "No mmc_id in the [%s] section" %
+                self.MAIN_SECTION)
         else:
             self._assert_matches_pattern(
                 r"[0-9]:[0-9]", mmc_id, "Invalid mmc_id %s" % mmc_id)
@@ -1230,6 +1292,16 @@ class Config(object):
             raise HwpackConfigError(
                 "Invalid samsung_bl1_len %s" % (samsung_bl1_len))
 
+    def _validate_samsung_env_start(self):
+        samsung_env_start = self.samsung_env_start
+        if samsung_env_start is None:
+            return
+        try:
+            assert int(samsung_env_start) > 0
+        except:
+            raise HwpackConfigError(
+                "Invalid samsung_env_start %s" % (samsung_env_start))
+
     def _validate_samsung_env_len(self):
         samsung_env_len = self.samsung_env_len
         if samsung_env_len is None:
@@ -1240,6 +1312,16 @@ class Config(object):
             raise HwpackConfigError(
                 "Invalid samsung_env_len %s" % (samsung_env_len))
 
+    def _validate_samsung_bl2_start(self):
+        samsung_bl2_start = self.samsung_bl2_start
+        if samsung_bl2_start is None:
+            return
+        try:
+            assert int(samsung_bl2_start) > 0
+        except:
+            raise HwpackConfigError(
+                "Invalid samsung_bl2_start %s" % (samsung_bl2_start))
+
     def _validate_samsung_bl2_len(self):
         samsung_bl2_len = self.samsung_bl2_len
         if samsung_bl2_len is None:
