@@ -29,7 +29,9 @@ from linaro_image_tools.hwpack.hwpack_fields import (
     SAMSUNG_BL1_LEN_FIELD,
     SAMSUNG_BL1_START_FIELD,
     SAMSUNG_BL2_LEN_FIELD,
+    SAMSUNG_BL2_START_FIELD,
     SAMSUNG_ENV_LEN_FIELD,
+    SAMSUNG_ENV_START_FIELD,
 )
 
 
@@ -39,32 +41,32 @@ class ConfigTests(TestCase):
         "name: ahwpack\npackages: foo\narchitectures: armel\n")
     valid_start_v3 = valid_start + "format: 3.0\n"
     valid_complete_v3 = (valid_start_v3 +
-        "serial_tty: ttySAC1\n"
-        "partition_layout:\n"
-        " - bootfs_rootfs\n"
-        "boot_script: boot.scr\n"
-        "extra_serial_options:\n"
-        "  - console=tty0\n"
-        "  - console=ttyO2,115200n8\n"
-        "mmc_id: 0:1\n"
-        "kernel_file: boot/vmlinuz-*-linaro-omap\n"
-        "initrd_file: boot/initrd.img-*-linaro-omap\n"
-        "dtb_file: boot/dt-*-linaro-omap/omap4-panda.dtb\n"
-        "bootloaders:\n"
-        " u_boot:\n"
-        "  package: u-boot-linaro-s5pv310\n"
-        "  file: usr/lib/u-boot/smdkv310/u-boot.bin\n"
-        "  spl_package: x-loader-omap4-panda\n"
-        "  spl_file: usr/lib/x-loader/omap4430panda/MLO\n"
-        "  in_boot_part: True\n"
-        "  extra_boot_options:\n"
-        "   - earlyprintk\n"
-        "   - fixrtc\n"
-        "   - nocompcache\n"
-        "   - vram=48M\n"
-        "   - omapfb.vram=0:24M\n"
-        "   - mem=456M@0x80000000\n"
-        "   - mem=512M@0xA0000000\n")
+                         "serial_tty: ttySAC1\n"
+                         "partition_layout:\n"
+                         " - bootfs_rootfs\n"
+                         "boot_script: boot.scr\n"
+                         "extra_serial_options:\n"
+                         "  - console=tty0\n"
+                         "  - console=ttyO2,115200n8\n"
+                         "mmc_id: 0:1\n"
+                         "kernel_file: boot/vmlinuz-*-linaro-omap\n"
+                         "initrd_file: boot/initrd.img-*-linaro-omap\n"
+                         "dtb_file: boot/dt-*-linaro-omap/omap4-panda.dtb\n"
+                         "bootloaders:\n"
+                         " u_boot:\n"
+                         "  package: u-boot-linaro-s5pv310\n"
+                         "  file: usr/lib/u-boot/smdkv310/u-boot.bin\n"
+                         "  spl_package: x-loader-omap4-panda\n"
+                         "  spl_file: usr/lib/x-loader/omap4430panda/MLO\n"
+                         "  in_boot_part: True\n"
+                         "  extra_boot_options:\n"
+                         "   - earlyprintk\n"
+                         "   - fixrtc\n"
+                         "   - nocompcache\n"
+                         "   - vram=48M\n"
+                         "   - omapfb.vram=0:24M\n"
+                         "   - mem=456M@0x80000000\n"
+                         "   - mem=512M@0xA0000000\n")
     valid_end = "sources:\n    sources-entry: foo bar\n"
 
     def test_create(self):
@@ -95,64 +97,64 @@ class ConfigTests(TestCase):
 
     def test_validate_invalid_include_debs(self):
         config = self.get_config(
-                "name: ahwpack\n"
-                "include_debs: if you don't mind\n")
+            "name: ahwpack\n"
+            "include_debs: if you don't mind\n")
         self.assertValidationError(
             "Invalid value for include-debs: if you don't mind",
             config._validate_include_debs)
 
     def test_validate_invalid_supported(self):
         config = self.get_config(
-                "name: ahwpack\nsupport: if you pay us\n")
+            "name: ahwpack\nsupport: if you pay us\n")
         self.assertValidationError(
             "Invalid value for support: if you pay us",
             config._validate_support)
 
     def test_validate_no_packages(self):
         config = self.get_config(
-                "name: ahwpack\n\n")
+            "name: ahwpack\n\n")
         self.assertValidationError(
             "No packages found in the metadata", config._validate_packages)
 
     def test_validate_empty_packages(self):
         config = self.get_config(
-                "name: ahwpack\npackages:  \n")
+            "name: ahwpack\npackages:  \n")
         self.assertValidationError(
             "No packages found in the metadata", config._validate_packages)
 
     def test_validate_invalid_package_name(self):
         config = self.get_config(
-                "name: ahwpack\npackages: foo  ~~ bar\n")
+            "name: ahwpack\npackages: foo  ~~ bar\n")
         self.assertValidationError(
             "Invalid value in packages in the metadata: ~~",
             config._validate_packages)
 
     def test_validate_no_architectures(self):
         config = self.get_config(
-                "name: ahwpack\npackages: foo\n")
+            "name: ahwpack\npackages: foo\n")
         self.assertValidationError(
             "No architectures found in the metadata",
             config._validate_architectures)
 
     def test_validate_empty_architectures(self):
         config = self.get_config(
-                "name: ahwpack\npackages: foo\n"
-                "architectures: \n")
+            "name: ahwpack\npackages: foo\n"
+            "architectures: \n")
         self.assertValidationError(
             "No architectures found in the metadata",
             config._validate_architectures)
 
     def test_validate_invalid_package_name_in_assume_installed(self):
         config = self.get_config(
-                "name: ahwpack\npackages: foo\n"
-                "architectures: armel\nassume_installed:\n - bar\n - ~~\n")
+            "name: ahwpack\npackages: foo\n"
+            "architectures: armel\nassume_installed:\n - bar\n - ~~\n")
         self.assertValidationError(
             "Invalid value in assume-installed in the metadata: ~~",
             config._validate_assume_installed)
 
     def test_validate_other_section_empty_sources_entry(self):
         config = self.get_config(
-                self.valid_start + "sources:\n ubuntu:  \n")
+            self.valid_start + "sources:\n ubuntu:  \n")
         self.assertValidationError(
             "The sources-entry, ubuntu is missing the URI",
             config._validate_sources)
@@ -165,14 +167,16 @@ class ConfigTests(TestCase):
             config._validate_sources)
 
     def test_validate_other_section_sources_entry_starting_with_deb(self):
-        config = self.get_config(self.valid_start +
-                  "sources:\n ubuntu: deb http://example.org/ foo main\n")
+        config = self.get_config(
+            self.valid_start +
+            "sources:\n ubuntu: deb http://example.org/ foo main\n")
         self.assertValidationError(
             "The sources-entry, ubuntu shouldn't start with 'deb'",
             config._validate_sources)
 
     def test_validate_other_section_sources_entry_starting_with_deb_src(self):
-        config = self.get_config(self.valid_start +
+        config = self.get_config(
+            self.valid_start +
             "sources:\n ubuntu: deb-src http://example.org/ foo main\n")
         self.assertValidationError(
             "The sources-entry, ubuntu shouldn't start with 'deb'",
@@ -243,7 +247,7 @@ class ConfigTests(TestCase):
                                  "bootloaders:\n"
                                  " u_boot:\n"
                                  "  spl_package: ~~\n")
-        config.set_board("panda")
+        config.board = "panda"
         self.assertValidationError(
             "Invalid value in spl_package in the metadata: ~~",
             config._validate_spl_package)
@@ -255,7 +259,7 @@ class ConfigTests(TestCase):
                                  "  bootloaders:\n"
                                  "   u_boot:\n"
                                  "    spl_file: ~~\n")
-        config.set_board("panda")
+        config.board = "panda"
         self.assertValidationError("Invalid path: ~~",
                                    config._validate_spl_file)
 
@@ -295,8 +299,8 @@ class ConfigTests(TestCase):
             "   u_boot:\n"
             "    in_boot_part: Yes\n")
 
-        config.set_bootloader("u_boot")
-        config.set_board("panda")
+        config.bootloader = "u_boot"
+        config.board = "panda"
 
         config._validate_bootloader_file_in_boot_part()
         self.assertEqual(config.bootloader_file_in_boot_part, "yes")
@@ -313,8 +317,8 @@ class ConfigTests(TestCase):
             "   u_boot:\n"
             "    in_boot_part: Yes\n")
 
-        config.set_bootloader("u_boot")
-        config.set_board("panda")
+        config.bootloader = "u_boot"
+        config.board = "panda"
 
         config._validate_bootloader_file_in_boot_part()
         self.assertEqual(config.bootloader_file_in_boot_part, "yes")
@@ -328,11 +332,11 @@ class ConfigTests(TestCase):
             " anotherboot:\n"
             "  in_boot_part: Yes\n")
 
-        config.set_bootloader("u_boot")
+        config.bootloader = "u_boot"
         config._validate_bootloader_file_in_boot_part()
         self.assertEqual(config.bootloader_file_in_boot_part, "no")
 
-        config.set_bootloader("anotherboot")
+        config.bootloader = "anotherboot"
         config._validate_bootloader_file_in_boot_part()
         self.assertEqual(config.bootloader_file_in_boot_part, "yes")
 
@@ -345,6 +349,13 @@ class ConfigTests(TestCase):
         self.assertValidationError("Invalid serial tty: ttxSAC1",
                                    config._validate_serial_tty)
 
+    def test_validate_mmc_id_wrong(self):
+        # The mmc_id value, if coming from a yaml file, has to be quoted.
+        # Make sure the test does not accept a valid-unquoted value.
+        config = self.get_config(self.valid_complete_v3 +
+                                 "mmc_id: 1:1\n")
+        self.assertRaises(HwpackConfigError, config._validate_mmc_id)
+
     def test_validate_mmc_id(self):
         config = self.get_config(self.valid_complete_v3 +
                                  "mmc_id: x\n")
@@ -509,11 +520,11 @@ class ConfigTests(TestCase):
             "omapfb.vram=0:24M mem=456M@0x80000000 mem=512M@0xA0000000",
             config.extra_boot_options)
 
-    def test_extra_serial_opts(self):
+    def test_extra_serial_options(self):
         config = self.get_config(self.valid_complete_v3 + self.valid_end)
         config.validate()
         self.assertEqual('console=tty0 console=ttyO2,115200n8',
-                         config.extra_serial_opts)
+                         config.extra_serial_options)
 
     def test_boot_script(self):
         config = self.get_config(self.valid_complete_v3 + self.valid_end)
@@ -816,12 +827,41 @@ class ConfigTests(TestCase):
                                  SAMSUNG_BL2_LEN_FIELD + ': 1\n')
         self.assertEqual(None, config._validate_keys())
 
+    def test_valid_samsung_bl2_start_field(self):
+        config = self.get_config(self.valid_start_v3 +
+                                 SAMSUNG_BL2_START_FIELD + ': 1\n')
+        self.assertEqual(None, config._validate_keys())
+
     def test_valid_samsung_env_len_field(self):
         config = self.get_config(self.valid_start_v3 +
                                  SAMSUNG_ENV_LEN_FIELD + ': 1\n')
         self.assertEqual(None, config._validate_keys())
 
+    def test_valid_samsung_env_start_field(self):
+        config = self.get_config(self.valid_start_v3 +
+                                 SAMSUNG_ENV_START_FIELD + ': 1\n')
+        self.assertEqual(None, config._validate_keys())
+
     def test_samsung_field_wrong(self):
         config = self.get_config(self.valid_start_v3 +
                                  'samsung_wrong_field: 1\n')
         self.assertRaises(HwpackConfigError, config._validate_keys)
+
+    # Tests for dtb_files support
+    def test_dtb_files(self):
+        dtb_files = ('dtb_files:\n' +
+                     ' - adest.dtb : boot/dt-*-linaro-omap/omap4-panda.dtb\n' +
+                     ' - bdest.dtb : ' +
+                     'boot/dt-*-linaro-omap2/omap4-panda2.dtb\n')
+        expected = [{'adest.dtb': 'boot/dt-*-linaro-omap/omap4-panda.dtb'},
+                    {'bdest.dtb': 'boot/dt-*-linaro-omap2/omap4-panda2.dtb'}]
+        config = self.get_config(self.valid_complete_v3 + dtb_files)
+        config.validate()
+        self.assertEqual(expected, config.dtb_files)
+
+    def test_dtb_files_one_wrong(self):
+        dtb_files = ('dtb_files:\n' +
+                     ' - adest.dtb : boot/dt-*-linaro-omap/omap4-panda.dtb\n' +
+                     ' - bdest.dtb : ~~~\n')
+        config = self.get_config(self.valid_start_v3 + dtb_files)
+        self.assertRaises(HwpackConfigError, config._validate_dtb_files)
