@@ -542,7 +542,7 @@ class BoardConfig(object):
         (loader_start, loader_len, boot_start, boot_len,
             root_start) = self.get_reserved_params(should_align_boot_part)
         return '-n 1:%s:%s -t 1:DA00 ' \
-               '-n 2:%s:%s -t 2:0C00 ' \
+               '-n 2:%s:%s -t 2:EF00 ' \
                '-n 3:%s:- -t 3:8300' % (
                    loader_start, loader_len, boot_start, boot_len, root_start)
 
@@ -939,7 +939,7 @@ class BoardConfig(object):
                         if not to_file:
                             to_file = os.path.basename(from_file)
                         dtb = _get_file_matching(os.path.join(path, from_file))
-        if not self.dtb_files or not dtb:
+        if not self.dtb_files and not dtb:
             logger.warn("Could not find a valid dtb file, skipping it.")
 
         logger.info("Will use kernel=%s, initrd=%s, dtb=%s." %
@@ -2083,7 +2083,10 @@ def _get_file_matching(regex):
 
     If zero or more than one files match, raise a ValueError.
     """
-    files = glob.glob(regex)
+    files = []
+    for fn in glob.glob(regex):
+        if not os.path.islink(fn):
+            files.append(fn)
     if len(files) == 1:
         return files[0]
     elif len(files) == 0:
